import { HttpClient } from '@angular/common/http';
import {Component, OnDestroy, OnInit} from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { Login } from './login';
import {DeploymentNotificationService} from '../services/deployment-notification.service';
import {Subscription} from 'rxjs/Subscription';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss']
})
export class LoginComponent implements OnInit, OnDestroy {
  model = new Login('', '');
  submitted = false;
  is_admin: boolean;
  logged_in_email: string;
  deploying = false;
  deploymentNotificationSubscription: Subscription;

  constructor(
    private http: HttpClient,
    private deploymentNotificationService: DeploymentNotificationService
  ) {}

  onSubmit() {
    this.postLogin(this.model).subscribe(
      res => {
        this.logged_in_email = res['email'];
        this.is_admin = res['is_admin'];
      }
    );
    this.submitted = true;
  }

  postLogin(login: Login): Observable<any> {
    return this.http.post<Login>('/login', login);
  }

  ngOnInit() {
    this.deploymentNotificationSubscription = this.deploymentNotificationService.deploying.subscribe(
      (deploying) => this.deploying = deploying
    );
  }

  ngOnDestroy() {
    if (this.deploymentNotificationSubscription) {
      this.deploymentNotificationSubscription.unsubscribe();
    }
  }
}
